@@ -14,7 +14,7 @@ function mkvenv {
 
     rm -rf $venv
     virtualenv $venv
-    $venv/bin/pip install $PIPFLAGS -U $PIPVERSION wheel
+    $venv/bin/pip install $PIPFLAGS -U $PIPVERSION wheel requests
 
     # If a change to PBR is being tested, preinstall the wheel for it
     if [ -n "$PBR_CHANGE" ] ; then
@@ -30,11 +30,17 @@ REPODIR=${REPODIR:-$BASE/new}
 
 # TODO: Figure out how to get this on to the box properly
 sudo apt-get update
-sudo apt-get install -y --force-yes libvirt-dev libxml2-dev libxslt-dev libmysqlclient-dev libpq-dev libnspr4-dev pkg-config libsqlite3-dev libzmq-dev libffi-dev libldap2-dev libsasl2-dev ccache
+sudo apt-get install -y --force-yes libvirt-dev libxml2-dev libxslt-dev libmysqlclient-dev libpq-dev libnspr4-dev pkg-config libsqlite3-dev libzmq-dev libffi-dev libldap2-dev libsasl2-dev ccache libkrb5-dev liberasurecode-dev libjpeg-dev
 
 # FOR numpy / pyyaml
-sudo apt-get build-dep -y --force-yes python-numpy
-sudo apt-get build-dep -y --force-yes python-yaml
+# The source list has been removed from our apt config so rather than
+# installing deps via apt-get build-dep <PKG> we install the lists provied
+# by apt-cache showsrc <PKG>
+
+# Numpy
+sudo apt-get install -y --force-yes cython debhelper gfortran libblas-dev liblapack-dev python-all-dbg python-all-dev python-nose python-tz python3-all-dbg python3-all-dev python3-nose python3-tz
+#pyyaml
+sudo apt-get install -y --force-yes debhelper python-all-dev python-all-dbg python3-all-dev python3-all-dbg libyaml-dev cython cython-dbg quilt
 
 # And use ccache explitly
 export PATH=/usr/lib/ccache:$PATH
@@ -100,11 +106,7 @@ EOF
 cat <<EOF > setup.py
 import setuptools
 
-try:
-    from requests import Timeout
-except ImportError:
-    from pip._vendor.requests import Timeout
-
+from requests import Timeout
 from socket import error as SocketError
 
 # Some environments have network issues that drop connections to pypi
@@ -163,4 +165,6 @@ export REPODIR
 export WHEELHOUSE
 export OS_TEST_TIMEOUT=600
 cd $REPODIR/pbr
+tox -epy27 --notest
+.tox/py27/bin/python -m pip install ${REPODIR}/requirements
 tox -epy27 -- test_integration
